# __init__.py
from .loc import *
from .func import *


def toCode(c, csi='\033['):
	"""
	Function for encode the transformation number `c`
	Param :
		- c [int or str] : ANSI code
	"""
	return f"{csi}{c}m"

def f(s, args):
	"""
	Function for transform the sentence `s` with transformations containt in `args`
	Param :
		- s [str]    : sentence to tranform
		- args [str] : all code wanted, separated with '.'

	Ex : 
		# For print 'Incroyable Test' underlined (tu), red (r), blink (tb), with green back :
		f('Incroyable Test', 'tu.r.tb.bg')
	"""
	full = ''.join([toCode(ansi[arg]) for arg in args.split('.')])
	print(f"{full}{s}{toCode(0)}")

def test():
	"""
	Function to test the coloralf package. No param.
	"""
	print(f"\nTest of coloralf :")

	print(f"\nTransformations : ")
	fti0('Week intensity   (ti0)')
	fti1('Normal intensity (ti1)')
	fti2('Strong intensity (ti2)')
	fti( 'Italic           (ti)')
	ftu( 'Underline        (tu)')
	ftu2('Double underline (tu2)')
	ftb( 'Blink            (tb)')
	print(f"{th}Hide{rh} (it's hide) (th)")
	ftc( 'Cross            (tc)')

	print("\nChange font color :")
	print(f"{k}Black   (k) {d}-{lk} Light Black   (lk){d}")
	print(f"{r}Red     (r) {d}-{lr} Light Red     (lr){d}")
	print(f"{g}Green   (g) {d}-{lg} Light Green   (lg){d}")
	print(f"{y}Yellow  (y) {d}-{ly} Light Yellow  (ly){d}")
	print(f"{b}Blue    (b) {d}-{lb} Light Blue    (lb){d}")
	print(f"{m}Magenta (k) {d}-{lm} Light Magenta (lm){d}")
	print(f"{c}Cyan    (k) {d}-{lc} Light Cyan    (lc){d}")
	print(f"{w}White   (k) {d}-{lw} Light White   (lw){d}")

	print("\nChange back color :")
	print(f"{bk}Black   (bk) {d}-{blk} Light Black   (blk){d}")
	print(f"{br}Red     (br) {d}-{blr} Light Red     (blr){d}")
	print(f"{bg}Green   (bg) {d}-{blg} Light Green   (blg){d}")
	print(f"{by}Yellow  (by) {d}-{bly} Light Yellow  (bly){d}")
	print(f"{bb}Blue    (bb) {d}-{blb} Light Blue    (blb){d}")
	print(f"{bm}Magenta (bk) {d}-{blm} Light Magenta (blm){d}")
	print(f"{bc}Cyan    (bk) {d}-{blc} Light Cyan    (blc){d}")
	print(f"{bw}White   (bk) {d}-{blw} Light White   (blw){d}")


d, ra, rall = '[0m', '[0m', '[0m' # Delete ALL transformation

### Transformation
# `t*` : to -> permit to apply the transformation
# `r*` : reset -> permit to remove the transformation
ti0, ti1, ti2 = '[1m', '[22m', '[2m' # Intensity (week, normal, strong)
ti, ri = '[3m', '[23m' # Italic
tu, ru = '[4m', '[24m' # Underline
tu2, tu2 = '[21m', '[24m' # Double Underline
tb, rb = '[5m', '[25m' # Blink
tr, rr = '[7m', '[27m' # Reset
th, rh = '[8m', '[28m' # Hide
tc, rc = '[9m', '[29m' # Cross

### Font Color (`l` for light) :
k, lk = '[30m', '[90m' # Black
r, lr = '[31m', '[91m' # Red
g, lg = '[32m', '[92m' # Green
y, ly = '[33m', '[93m' # Yellow
b, lb = '[34m', '[94m' # Blue
m, lm = '[35m', '[95m' # Magenta
c, lc = '[36m', '[96m' # Cyan
w, lw = '[37m', '[97m' # White
rfc = '[39m' # Reset font color

### Back Color (`l` for light) :
bk, blk = '[40m', '[100m' # Black
br, blr = '[41m', '[101m' # Red
bg, blg = '[42m', '[102m' # Green
by, bly = '[43m', '[103m' # Yellow
bb, blb = '[44m', '[104m' # Blue
bm, blm = '[45m', '[105m' # Magenta
bc, blc = '[46m', '[106m' # Cyan
bw, blw = '[47m', '[107m' # White
rbc = '[49m' # Reset back color




### Transformation
# `t*` : to -> permit to apply the transformation
# Intensity (week, normal, strong)
fti0 = lambda s : print(f"[2m{s}[0m")
fti1 = lambda s : print(f"[22m{s}[0m")
fti2 = lambda s : print(f"[1m{s}[0m")
# Italic
fti = lambda s : print(f"[3m{s}[0m")
# Underline
ftu = lambda s : print(f"[4m{s}[0m")
# Double Underline
ftu2 = lambda s : print(f"[21m{s}[0m")
# Blink
ftb = lambda s : print(f"[5m{s}[0m")
# Hide
fth = lambda s : print(f"[8m{s}[0m")
# Cross
ftc = lambda s : print(f"[9m{s}[0m")

### Font Color (`l` for light) :
# Black
fk = lambda s : print(f"[30m{s}[0m")
flk = lambda s : print(f"[90m{s}[0m")
# Red
fr = lambda s : print(f"[31m{s}[0m")
flr = lambda s : print(f"[91m{s}[0m")
# Green
fg = lambda s : print(f"[32m{s}[0m")
flg = lambda s : print(f"[92m{s}[0m")
# Yellow
fy = lambda s : print(f"[33m{s}[0m")
fly = lambda s : print(f"[93m{s}[0m")
# Blue
fb = lambda s : print(f"[34m{s}[0m")
flb = lambda s : print(f"[94m{s}[0m")
# Magenta
fm = lambda s : print(f"[35m{s}[0m")
flm = lambda s : print(f"[95m{s}[0m")
# Cyan
fc = lambda s : print(f"[36m{s}[0m")
flc = lambda s : print(f"[96m{s}[0m")
# White
fw = lambda s : print(f"[37m{s}[0m")
flw = lambda s : print(f"[97m{s}[0m")

### Back Color (`l` for light) :
# Black
fbk = lambda s : print(f"[40m{s}[0m")
fblk = lambda s : print(f"[100m{s}[0m")
# Red
fbr = lambda s : print(f"[41m{s}[0m")
fblr = lambda s : print(f"[101m{s}[0m")
# Green
fbg = lambda s : print(f"[42m{s}[0m")
fblg = lambda s : print(f"[102m{s}[0m")
# Yellow
fby = lambda s : print(f"[43m{s}[0m")
fbly = lambda s : print(f"[103m{s}[0m")
# Blue
fbb = lambda s : print(f"[44m{s}[0m")
fblb = lambda s : print(f"[104m{s}[0m")
# Magenta
fbm = lambda s : print(f"[45m{s}[0m")
fblm = lambda s : print(f"[105m{s}[0m")
# Cyan
fbc = lambda s : print(f"[46m{s}[0m")
fblc = lambda s : print(f"[106m{s}[0m")
# White
fbw = lambda s : print(f"[47m{s}[0m")
fblw = lambda s : print(f"[107m{s}[0m")



from setuptools import setup, find_packages

with open("README.md", "r") as f:
	desc = f.read()

setup(
	name='coloralf',
	version='0.3',
	packages=find_packages(),
	install_requires=[],

	description="Simple package to easy color & transform your console string and output",
	long_description=desc,
	long_description_content_type="text/markdown",
	author="Aexeos - Angelo LF",
	author_email="aexeos413@gmail.com"
)